import { joinUser, taskFile, getViewLogList, codeFile, taskList } from '@/api/table'
import { getToken } from '@/utils/auth'

const user = {
  state: {
    uid: getToken(),
    joinUserList: [],
    fileList: [],
    logList: [],
    codeList: [],
    totalSize: 0,
    logSize: 0
  },

  mutations: {
    SET_JOINUSERLIST: (state, list) => {
      state.joinUserList = list
    },
    SET_FILELIST: (state, data) => {
      state.fileList = [...data.localFile, ...data.screenshot, ...data.mergeFile, ...data.recordFile]
    },
    SET_LOGLIST: (state, data) => {
      state.logList = data.list
      state.logSize = data.totalSize
    },
    SET_TOTALSIZE: (state, size) => {
      state.totalSize = size
    },
    SET_CODELIST: (state, data) => {
      state.codeList = [...data.localFile, ...data.screenshot]
    }
  },

  actions: {
    // 获取参会人员
    JoinUser({ commit, state }, pageNo) {
      return new Promise((resolve, reject) => {
        joinUser(getToken(), pageNo, 10).then(response => {
          const data = response.data
          commit('SET_JOINUSERLIST', data.list)
          commit('SET_TOTALSIZE', data.totalSize)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取参会文件
    TaskFile({ commit }, taskId) {
      return new Promise((resolve, reject) => {
        taskFile(taskId).then(response => {
          console.log(response)
          const data = response.data
          commit('SET_FILELIST', data)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取浏览信息
    GetViewLogList({ commit }, pageNo) {
      return new Promise((resolve, reject) => {
        getViewLogList(pageNo, 10).then(response => {
          const data = response.data
          commit('SET_LOGLIST', data)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 输入授权码获取会议资料
    CodeFile({ commit, state }, code) {
      return new Promise((resolve, reject) => {
        codeFile(code).then(response => {
          const data = response.data
          commit('SET_JOINUSERLIST', data)
          // commit('SET_TOTALSIZE', data.totalSize)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取会议文件
    TaskList({ commit, state }, pageNo) {
      return new Promise((resolve, reject) => {
        taskList(getToken(), pageNo, 10).then(response => {
          const data = response.data
          commit('SET_JOINUSERLIST', data.list)
          commit('SET_TOTALSIZE', data.totalSize)
          resolve(data.list)
        }).catch(error => {
          reject(error)
        })
      })
    }
  }
}

export default user
